@@ -1,7 +1,7 @@
 from httpx import AsyncClient
 from fake_useragent import UserAgent
 import random
-from re import compile, findall
+from re import findall
 import sqlite3
 import os
 
@@ -30,19 +30,8 @@ def get_userid(event):
     return id_
 
 
-def get_userimg(event):
-    img_info = str(event.get_message())
-    url_pattern = compile(r'url=(?P<url>.*?)]')
-    try:
-        img_url = findall(url_pattern, img_info)[0]
-    except IndexError:
-        return None
-    else:
-        return img_url
-
-
-def random_prompt(num):
-    num = int(num)
+def random_prompt(order):
+    num = int(order)
     db_path = os.path.join(os.path.abspath(os.path.dirname(__file__)), "resource", "novelai_tags.db")
     conn = sqlite3.connect(db_path)
     cur = conn.cursor()
@@ -50,7 +39,7 @@ def random_prompt(num):
     cur.execute(f"select 英文词条 from  main_tags limit {num} offset {off}")
     tags = cur.fetchall()
 
-    prompt = "{{Masterpiece}}, {{best quality}}, beautifully painted, highly detailed, highres, Stunning art"
+    prompt = "masterpiece, best quality, highly detailed"
     for tag in tags:
         prompt += ", " + tag[0]
 
@@ -80,12 +69,11 @@ async def search_tags(tag, proxies):
 
 
 async def get_data(
-    post_url, prompt, proxies,
-    img=None, mode=None, strength=None,
-    noise=None, size=None, uc=None,
-    scale=None, steps=None, seed=None
+        post_url, prompt, proxies,
+        img=None, mode=None, strength=None,
+        noise=None, size=None, uc=None,
+        scale=None, steps=None, seed=None
 ):
-
     data = {
         "width": size[0],
         "height": size[1],
@@ -114,15 +102,14 @@ async def get_data(
 
     async with AsyncClient(headers=headers, proxies=proxies) as client:
         try:
-            resp = await client.post(url=post_url, json=data, timeout=90)
+            resp = await client.post(url=post_url, json=data)
         except Exception as error:
             return False, error
         info = resp.text
 
-        # 获取错误原因
+        # 获取错误
         if "error" in info:
-            error = findall(r'"error":"(?P<error>.*?)"', info)[0]
-            return False, error
+            return False, info
 
         # 获取返回的图片base64
         base64_img = findall(r'data:(?P<base64>.*)', info)[0]
